@@ -60,8 +60,10 @@ class Config(object):
                                 'username': '',
                                 'password': '',
                                 'use_keystone': True,
+                                'keystone_timeout': 20,
                                 'keystone_url': '',
                                 'max_buffer_size': 1000,
+                                'write_timeout': 10,
                                 'backlog_send_rate': 5},
                         'Statsd': {'recent_point_threshold': None,
                                    'monasca_statsd_interval': 20,
