@@ -2,8 +2,8 @@
 
     Detection classes should be platform independent
 """
-import sys
 import logging
+import sys
 
 log = logging.getLogger(__name__)
 
@@ -16,14 +16,17 @@ class Plugin(object):
         self.template_dir = template_dir
         self.dependencies = ()
         self.overwrite = overwrite
-        self.args = None
-        if args is not None:
+        if args is not None and isinstance(args, str):
             try:
                 # Turn 'hostname=host type=ping' to dictionary {'hostname': 'host', 'type': 'ping'}
                 self.args = dict([a.split('=') for a in args.split()])
             except Exception:
                 log.exception('Error parsing detection arguments')
                 sys.exit(1)
+        elif isinstance(args, dict):
+            self.args = args
+        else:
+            self.args = None
         self._detect()
 
     def _detect(self):
@@ -39,8 +42,8 @@ class Plugin(object):
         raise NotImplementedError
 
     def build_config_with_name(self):
-        """ Builds the config and then adds a field 'built_by' to each instance in the config.
-            built_by is set to the plugin name
+        """Builds the config and then adds a field 'built_by' to each instance in the config.
+           built_by is set to the plugin name
         :return: An agent_config.Plugins object
         """
         conf = self.build_config()
